@@ -21,7 +21,7 @@
  */
 
 #include "xftint.h"
-   
+
 _X_EXPORT void
 XftGlyphExtents (Display	    *dpy,
 		 XftFont	    *pub,
@@ -41,7 +41,7 @@ XftGlyphExtents (Display	    *dpy,
     int			left, right, top, bottom;
     int			overall_left, overall_right;
     int			overall_top, overall_bottom;
-    
+
     g = glyphs;
     n = nglyphs;
     nmissing = 0;
@@ -53,7 +53,7 @@ XftGlyphExtents (Display	    *dpy,
 	XftFontLoadGlyphs (dpy, pub, FcFalse, missing, nmissing);
     g = glyphs;
     n = nglyphs;
-    xftg = 0;
+    xftg = NULL;
     while (n)
     {
 	glyph = *g++;
@@ -100,12 +100,12 @@ XftGlyphExtents (Display	    *dpy,
 		y += xftg->metrics.yOff;
 	    }
 	}
-	extents->x = -overall_left;
-	extents->y = -overall_top;
-	extents->width = overall_right - overall_left;
-	extents->height = overall_bottom - overall_top;
-	extents->xOff = x;
-	extents->yOff = y;
+	extents->x = (short)(-overall_left);
+	extents->y = (short)(-overall_top);
+	extents->width = (unsigned short)(overall_right - overall_left);
+	extents->height = (unsigned short)(overall_bottom - overall_top);
+	extents->xOff = (short)x;
+	extents->yOff = (short)y;
     }
     if (glyphs_loaded)
 	_XftFontManageMemory (dpy, pub);
@@ -116,7 +116,7 @@ XftGlyphExtents (Display	    *dpy,
 _X_EXPORT void
 XftTextExtents8 (Display	    *dpy,
 		 XftFont	    *pub,
-		 _Xconst FcChar8    *string, 
+		 _Xconst FcChar8    *string,
 		 int		    len,
 		 XGlyphInfo	    *extents)
 {
@@ -127,7 +127,7 @@ XftTextExtents8 (Display	    *dpy,
 	glyphs = glyphs_local;
     else
     {
-	glyphs = malloc (len * sizeof (FT_UInt));
+	glyphs = malloc ((size_t)len * sizeof (FT_UInt));
 	if (!glyphs)
 	{
 	    memset (extents, '\0', sizeof (XGlyphInfo));
@@ -144,7 +144,7 @@ XftTextExtents8 (Display	    *dpy,
 _X_EXPORT void
 XftTextExtents16 (Display	    *dpy,
 		  XftFont	    *pub,
-		  _Xconst FcChar16  *string, 
+		  _Xconst FcChar16  *string,
 		  int		    len,
 		  XGlyphInfo	    *extents)
 {
@@ -155,7 +155,7 @@ XftTextExtents16 (Display	    *dpy,
 	glyphs = glyphs_local;
     else
     {
-	glyphs = malloc (len * sizeof (FT_UInt));
+	glyphs = malloc ((size_t)len * sizeof (FT_UInt));
 	if (!glyphs)
 	{
 	    memset (extents, '\0', sizeof (XGlyphInfo));
@@ -172,7 +172,7 @@ XftTextExtents16 (Display	    *dpy,
 _X_EXPORT void
 XftTextExtents32 (Display	    *dpy,
 		  XftFont	    *pub,
-		  _Xconst FcChar32  *string, 
+		  _Xconst FcChar32  *string,
 		  int		    len,
 		  XGlyphInfo	    *extents)
 {
@@ -183,7 +183,7 @@ XftTextExtents32 (Display	    *dpy,
 	glyphs = glyphs_local;
     else
     {
-	glyphs = malloc (len * sizeof (FT_UInt));
+	glyphs = malloc ((size_t)len * sizeof (FT_UInt));
 	if (!glyphs)
 	{
 	    memset (extents, '\0', sizeof (XGlyphInfo));
@@ -200,7 +200,7 @@ XftTextExtents32 (Display	    *dpy,
 _X_EXPORT void
 XftTextExtentsUtf8 (Display	    *dpy,
 		    XftFont	    *pub,
-		    _Xconst FcChar8 *string, 
+		    _Xconst FcChar8 *string,
 		    int		    len,
 		    XGlyphInfo	    *extents)
 {
@@ -217,7 +217,7 @@ XftTextExtentsUtf8 (Display	    *dpy,
     {
 	if (i == size)
 	{
-	    glyphs_new = malloc (size * 2 * sizeof (FT_UInt));
+	    glyphs_new = malloc ((size_t)size * 2 * sizeof (FT_UInt));
 	    if (!glyphs_new)
 	    {
 		if (glyphs != glyphs_local)
@@ -225,7 +225,7 @@ XftTextExtentsUtf8 (Display	    *dpy,
 		memset (extents, '\0', sizeof (XGlyphInfo));
 		return;
 	    }
-	    memcpy (glyphs_new, glyphs, size * sizeof (FT_UInt));
+	    memcpy (glyphs_new, glyphs, (size_t)size * sizeof (FT_UInt));
 	    size *= 2;
 	    if (glyphs != glyphs_local)
 		free (glyphs);
@@ -243,7 +243,7 @@ XftTextExtentsUtf8 (Display	    *dpy,
 _X_EXPORT void
 XftTextExtentsUtf16 (Display		*dpy,
 		     XftFont		*pub,
-		     _Xconst FcChar8	*string, 
+		     _Xconst FcChar8	*string,
 		     FcEndian		endian,
 		     int		len,
 		     XGlyphInfo		*extents)
@@ -261,7 +261,7 @@ XftTextExtentsUtf16 (Display		*dpy,
     {
 	if (i == size)
 	{
-	    glyphs_new = malloc (size * 2 * sizeof (FT_UInt));
+	    glyphs_new = malloc ((size_t)size * 2 * sizeof (FT_UInt));
 	    if (!glyphs_new)
 	    {
 		if (glyphs != glyphs_local)
@@ -269,7 +269,7 @@ XftTextExtentsUtf16 (Display		*dpy,
 		memset (extents, '\0', sizeof (XGlyphInfo));
 		return;
 	    }
-	    memcpy (glyphs_new, glyphs, size * sizeof (FT_UInt));
+	    memcpy (glyphs_new, glyphs, (size_t)size * sizeof (FT_UInt));
 	    size *= 2;
 	    if (glyphs != glyphs_local)
 		free (glyphs);
